#
# spec file for package gnu-efi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnu-efi
Version:        3.0.3
Release:        1.3
Summary:        Library for EFI Applications
License:        BSD-3-Clause and GPL-2.0+
Group:          Development/Libraries/Other
Url:            http://sourceforge.net/projects/gnu-efi
Source:         http://sourceforge.net/projects/gnu-efi/files/gnu-efi-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
Patch1:         gnu-efi-add-missing-unions.patch
# PATCH-FIX-SUSE gnu-efi-bsc978586-keep-order.patch bsc#978586 glin@suse.com -- Keep the order of the object files for shim
Patch2:         gnu-efi-bsc978586-keep-order.patch
BuildRequires:  kernel-source
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  ia64 %ix86 x86_64 aarch64 %arm

%description
Library to develop EFI applications for IA-64 (IPF), IA-32 (x86), x86_64,
ARM-32, and ARM-64 platforms using the GNU toolchain and the EFI development
environment.

%prep
%setup -q
%patch1 -p1
%ifarch x86_64
%patch2 -p1
%endif

%build
##########################
## DO NOT ADD RPM OPT FLAGS! THIS DOES NOT BUILD AGAINST GLIBC
##
##########################
make %{?_smp_mflags} LINUX_HEADERS=%{_prefix}/src/linux

%install
make install INSTALLROOT=%{buildroot} LIBDIR=%{_libdir} PREFIX=%{_prefix}
%if 0
mkdir %{buildroot}%{_libdir}/%{name}
cp -p apps/*.efi %{buildroot}%{_libdir}/%{name}
%endif

%files
%defattr(-, root, root)
%doc README.*
%{_includedir}/efi
%{_libdir}/crt0-efi-*.o
%{_libdir}/elf_*_efi.lds
%{_libdir}/libefi.a
%{_libdir}/libgnuefi.a
%if 0
%{_libdir}/%{name}
%endif

%changelog
* Thu May  5 2016 glin@suse.com
- Add gnu-efi-order-hack.patch to keep the order of the object
  files (bsc#978586)
* Fri Feb 26 2016 glin@suse.com
- Update to gnu-efi 3.0.3
  + Add the definition of URI Device Path according to UEFI 2.4c
  + Turns out we actually need setjmp in one of gnu-efi's prominent
    users, and it seems to make more sense to put it here than in
    the application.
  + _SPrint: fix NULL termination
  + Add current OsIndications values
  + Add the QueryVariableInfo() API
  + Add the capsule API
  + Add the missing Variable attributes
  + document that binutils >= 2.24 needed
  + allow to use external stdarg.h
  + Add support for 32-bit ARM
  + Add support for 64-bit ARM (AArch64)
  + Use OpenProtocol instead of HandleProtocol
  + inc/efistdarg.h: Use gcc builtins instead of stdarg.h or
    broken stubs
  + always observe EFIAPI calling convention when calling
    STO.SetAttribute
  + Add VPoolPrint Function
  + patch for "DevicePathToStr()" to display device path according
    to UEFI 2 specification
  + Add support for the simple pointer and absolute pointer
    protocols
  + Initialize Status before calling GrowBuffer()
  + Implement VSPrint function, prints a formatted unicode string
    to a buffer
  + Added support for SetVariable to store volatile variable, and
    SetNVVariable to store non volatile variable.
  + Atoi needs to have consistent declaration/definition
  + Fix compilation on x86_64 without HAVE_USE_MS_ABI
- Add gnu-efi-add-missing-unions.patch to add the missing entries
  in the device path unions
* Wed Jul 17 2013 glin@suse.com
- Update to gnu-efi 3.0u
  + Disable MMX and SSE to avoid using the uninitialized registers
  + Support .text.* sections on x86_64
  + Automatically determine number of uefi_call_wrapper() args on
    x86_64
  + Fix parameter-passing corruption on x86_64 for >= 5 args
  + Add the definitions for TCP, UDP and IP, for both IPv4 and IPv6
  + Fix UEFI functions that use the wrong ABI (System V ABI)
  + Use new gcc flag: GNU_EFI_USE_MS_ABI
  + Add new status codes to efierr.h
  + Align stack properly to avoid crash
  + Support UEFI PXE over IPv6
* Wed Nov  7 2012 dmueller@suse.com
- revert last change as it breaks the app completely
* Wed Jul 18 2012 meissner@suse.com
- cleaned below up, pass in OPTFLAGS and LIBDIR to make.
* Wed Jul 18 2012 malcolmlewis@opensuse.org
- Add gnu-efi-add-optflags-to-make-defaults.patch: Add additional
  RPM OPT FLAGS to Make.defaults to avoid brp check warning.
- Spec file clean up and rename rpmlintrc file.
* Thu Jun 14 2012 glin@suse.com
- Update to gnu-efi 3.0q
  + Fix .reloc section to support UEFI Secure Boot
  + Fix redefined types compilation failure on x86_64 machines
  + Conditionally assign toolchain binaries to allow overriding
    them
  + Force a dependency on lib for gnuefi
  + Add guarantee 16-byte stack alignment on x86_64
  + Add routine to make callbacks work
  + Add apps/tcc.efi to test calling convention
  + Add ifdefs for ia64 to mirror ia32 and x86-64 so that
    one can build with GCC.
  + Add headers for PciIo
  + Add the UEFI 2.x bits for EFI_BOOT_SERVICES
  + Add an ignore for .note.GNU-stack section in X86-64 linker maps
  + Change license from GPL to BSD
  + Fix elf_ia32_efi.lds linker script to be compatible with the
    new linker behaviour
  + Fix to not having any relocations at all
  + Add setjmp/longjmp
  + Fixes incorrect section attribute in crt0-efi-ia32.S
  + Adds value EfiResetShutdown to enum EFI_RESET_TYPE
  + Fixes a RAW warning in reloc_ia64.S
  + Adds the USB HCI device path structure in the headers
  + Added '-mno-red-zone' to x68_64 compiles
* Fri Oct 17 2008 olh@suse.de
- add ExclusiveArch ia64 x86 x86_64
* Tue Jul 29 2008 rw@suse.de
- Update to gnu-efi 3.0e for uEFI/x86_64.  (fate#301882)
* Sat May 26 2007 schwab@suse.de
- Remove completely pointless devel package.
- Add rpmlintrc instead.
* Sat May 26 2007 ro@suse.de
- Split off devel package.
* Fri Feb 23 2007 schwab@suse.de
- Disable stack protector.
* Fri Jun 23 2006 rw@suse.de
- Update to gnu-efi 3.0c to fix building on IA-32.
* Wed Jan 25 2006 mls@suse.de
- Convert neededforbuild to BuildRequires
* Fri Dec  9 2005 rw@suse.de
- Allow building on IA-32.
* Tue Nov 29 2005 rw@suse.de
- Update to gnu-efi 3.0b-041222.
* Tue Aug  3 2004 schwab@suse.de
- Discard unwind sections.
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Fri Sep 26 2003 schwab@suse.de
- Fix linker script to include all data sections.
* Fri Jul 25 2003 schwab@suse.de
- Revert last change, was actually a binutils bug.
* Tue Apr  8 2003 schwab@suse.de
- Fix @gprel reference in crt object.
* Tue Feb 26 2002 schwab@suse.de
- Update to gnu-efi 3.0a.
* Sat Nov 24 2001 schwab@suse.de
- Add .rodata.* to linker script.
* Wed Jul 18 2001 schwab@suse.de
- Update to gnu-efi 3.0.
- Split off elilo.
* Tue May 22 2001 schwab@suse.de
- Update to gnu-efi 2.5.
* Fri May 11 2001 schwab@suse.de
- Add initrd fix.
- Reduce timeout.
* Thu Apr 26 2001 schwab@suse.de
- neededforbuild lx_ia64 -> kernel-source.
* Fri Apr  6 2001 schwab@suse.de
- Update to gnu-efi 2.0.
- Package renamed to gnu-efi.
* Tue Mar 13 2001 schwab@suse.de
- Install some documentation.
- Add unwind patch from David Mosberger.
* Wed Feb 14 2001 schwab@suse.de
- Add lx_ia64 to neededforbuild.
- Get kernel headers from /usr/src/linux.
* Sun Nov 26 2000 schwab@suse.de
- Preserve .sdata section.
* Mon Nov  6 2000 schwab@suse.de
- Update to gnu-efi 1.1.
- Add `initrd=initrd' to sample eli.cfg.
* Fri Oct 13 2000 schwab@suse.de
- Update to gnu-efi 1.0.
* Mon Sep 11 2000 schwab@suse.de
- Mark startup.nsh as %%config(noreplace).
* Thu Aug 17 2000 schwab@suse.de
- Fix initrd support.
* Tue Aug  8 2000 schwab@suse.de
- Update to gnu-efi 0.9.
- Install lilo.efi in /boot.
* Mon Jul 17 2000 schwab@suse.de
- Add argv bug fix.
* Fri Jun 30 2000 schwab@suse.de
- Update to 0.4.0.
- Fix uninitialized variable.
* Fri Jun 16 2000 @suse.de
- Update from CVS.
* Mon Jun  5 2000 schwab@suse.de
- Add initrd support.
* Wed May 31 2000 schwab@suse.de
- Fix allocation bug.
* Wed May 17 2000 schwab@suse.de
- Add eli.cfg and startup.nsh to package.
* Mon May 15 2000 schwab@suse.de
- Fix bug in AML parser.
- Udate to gnu-efi 0.8.
* Tue Mar  7 2000 schwab@suse.de
- Package created.
